Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(629)

Unified Diff: chrome/browser/sync/test/integration/updated_progress_marker_checker.cc

Issue 2258873003: [Sync] Move sessions/ to engine/cycle/ and rename things to match. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address comments. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/test/integration/updated_progress_marker_checker.cc
diff --git a/chrome/browser/sync/test/integration/updated_progress_marker_checker.cc b/chrome/browser/sync/test/integration/updated_progress_marker_checker.cc
index 7e5f70970e7a2815598563bf527e046b6e5ff388..de6ca103165b409e60e4bdf735bcb8c0f56e8885 100644
--- a/chrome/browser/sync/test/integration/updated_progress_marker_checker.cc
+++ b/chrome/browser/sync/test/integration/updated_progress_marker_checker.cc
@@ -5,7 +5,7 @@
#include "chrome/browser/sync/test/integration/updated_progress_marker_checker.h"
#include "components/browser_sync/browser/profile_sync_service.h"
-#include "components/sync/sessions/sync_session_snapshot.h"
+#include "components/sync/engine/cycle/sync_cycle_snapshot.h"
UpdatedProgressMarkerChecker::UpdatedProgressMarkerChecker(
ProfileSyncService* service) : SingleClientStatusChangeChecker(service) {}
@@ -25,7 +25,7 @@ bool UpdatedProgressMarkerChecker::IsExitConditionSatisfied() {
//
// There is a subtle race condition here. While committing items, the syncer
// will unset the IS_UNSYNCED bits in the directory. However, the evidence of
// this current sync cycle won't be available from GetLastSessionSnapshot()
// until the sync cycle completes. If we query this condition between the
// commit response processing and the end of the sync cycle, we could return a
// false positive.
@@ -35,8 +35,7 @@ bool UpdatedProgressMarkerChecker::IsExitConditionSatisfied() {
// sync session complete or other significant event from the
// ProfileSyncService. If we're calling this right after the sync session
// completes, then the snapshot is much more likely to be up to date.
- const syncer::sessions::SyncSessionSnapshot& snap =
- service()->GetLastSessionSnapshot();
+ const syncer::SyncCycleSnapshot& snap = service()->GetLastCycleSnapshot();
return snap.model_neutral_state().num_successful_commits == 0 &&
service()->IsSyncActive() && !service()->HasUnsyncedItems();
}
@@ -25,7 +25,7 @@ bool UpdatedProgressMarkerChecker::IsExitConditionSatisfied() {
// There is a subtle race condition here. While committing items, the syncer
// will unset the IS_UNSYNCED bits in the directory. However, the evidence of
- // this current sync cycle won't be available from GetLastSessionSnapshot()
+ // this current sync cycle won't be available from GetLastCycleSnapshot()
// until the sync cycle completes. If we query this condition between the
// commit response processing and the end of the sync cycle, we could return a

Powered by Google App Engine
This is Rietveld 408576698